@@ -1,6 +1,6 @@
 package Langertha::Engine::Anthropic;
 # ABSTRACT: Anthropic API
-our $VERSION = '0.200';
+our $VERSION = '0.201';
 use Moose;
 use Carp qw( croak );
 use JSON::MaybeXS;
@@ -100,15 +100,19 @@ sub chat_request {
 sub chat_response {
   my ( $self, $response ) = @_;
   my $data = $self->parse_response($response);
-  my @messages = @{$data->{content}};
+  my @blocks = @{$data->{content}};
+  my $text = join('', map { $_->{text} // '' } grep { $_->{type} eq 'text' } @blocks);
+  my @thinking = map { $_->{thinking} // '' } grep { $_->{type} eq 'thinking' } @blocks;
+  my $thinking = @thinking ? join("\n", @thinking) : undef;
   require Langertha::Response;
   return Langertha::Response->new(
-    content       => $messages[0]->{text} // '',
+    content       => $text,
     raw           => $data,
     $data->{id} ? ( id => $data->{id} ) : (),
     $data->{model} ? ( model => $data->{model} ) : (),
     defined $data->{stop_reason} ? ( finish_reason => $data->{stop_reason} ) : (),
     $data->{usage} ? ( usage => $data->{usage} ) : (),
+    defined $thinking ? ( thinking => $thinking ) : (),
   );
 }
 
@@ -322,7 +326,7 @@ Langertha::Engine::Anthropic - Anthropic API
 
 =head1 VERSION
 
-version 0.200
+version 0.201
 
 =head1 SYNOPSIS
 
@@ -417,7 +421,9 @@ seconds (default: 3600). Pass C<force_refresh => 1> to bypass the cache.
 
 =item * L<Langertha::Role::Tools> - MCP tool calling interface
 
-=item * L<Langertha> - Main Langertha documentation
+=item * L<Langertha::Role::Streaming> - Streaming support (SSE format)
+
+=item * L<Langertha::Engine::Gemini> - Another non-OpenAI-compatible engine
 
 =back
 
