@@ -1,6 +1,6 @@
 package Langertha::Engine::Gemini;
 # ABSTRACT: Google Gemini API
-our $VERSION = '0.200';
+our $VERSION = '0.201';
 use Moose;
 use Carp qw( croak );
 use JSON::MaybeXS;
@@ -106,15 +106,27 @@ sub chat_response {
   my ( $self, $response ) = @_;
   my $data = $self->parse_response($response);
 
-  # Gemini response format: candidates[0].content.parts[0].text
+  # Gemini response format: candidates[0].content.parts[].text
   my $candidates = $data->{candidates} || [];
   my $text = '';
   my $finish_reason;
+  my $thinking;
   if (@$candidates) {
     my $candidate = $candidates->[0];
     my $content = $candidate->{content} || {};
     my $parts = $content->{parts} || [];
-    $text = $parts->[0]->{text} || '' if @$parts;
+    my @text_parts;
+    my @thought_parts;
+    for my $part (@$parts) {
+      next unless exists $part->{text};
+      if ($part->{thought}) {
+        push @thought_parts, $part->{text};
+      } else {
+        push @text_parts, $part->{text};
+      }
+    }
+    $text = join('', @text_parts);
+    $thinking = join("\n", @thought_parts) if @thought_parts;
     $finish_reason = $candidate->{finishReason};
   }
 
@@ -135,6 +147,7 @@ sub chat_response {
     $data->{modelVersion} ? ( model => $data->{modelVersion} ) : (),
     defined $finish_reason ? ( finish_reason => $finish_reason ) : (),
     $usage ? ( usage => $usage ) : (),
+    defined $thinking ? ( thinking => $thinking ) : (),
   );
 }
 
@@ -373,7 +386,7 @@ Langertha::Engine::Gemini - Google Gemini API
 
 =head1 VERSION
 
-version 0.200
+version 0.201
 
 =head1 SYNOPSIS
 
@@ -448,7 +461,9 @@ for C<models_cache_ttl> seconds (default: 3600).
 
 =item * L<Langertha::Role::Tools> - MCP tool calling interface
 
-=item * L<Langertha> - Main Langertha documentation
+=item * L<Langertha::Role::Streaming> - Streaming support (SSE format)
+
+=item * L<Langertha::Engine::Anthropic> - Another non-OpenAI-compatible engine
 
 =back
 
