@@ -1,10 +1,23 @@
 package Langertha::Engine::vLLM;
 # ABSTRACT: vLLM inference server
-our $VERSION = '0.200';
+our $VERSION = '0.201';
 use Moose;
 use Carp qw( croak );
 
-extends 'Langertha::Engine::OpenAI';
+with 'Langertha::Role::'.$_ for (qw(
+  JSON
+  HTTP
+  OpenAICompatible
+  OpenAPI
+  Models
+  Temperature
+  ResponseSize
+  SystemPrompt
+  Streaming
+  Chat
+));
+
+with 'Langertha::Role::Tools';
 
 
 has '+url' => (
@@ -20,6 +33,8 @@ sub _build_supported_operations {[qw(
   createCompletion
 )]}
 
+__PACKAGE__->meta->make_immutable;
+
 
 1;
 
@@ -35,7 +50,7 @@ Langertha::Engine::vLLM - vLLM inference server
 
 =head1 VERSION
 
-version 0.200
+version 0.201
 
 =head1 SYNOPSIS
 
@@ -63,8 +78,8 @@ version 0.200
 =head1 DESCRIPTION
 
 Provides access to vLLM, a high-throughput inference engine for large
-language models. Extends L<Langertha::Engine::OpenAI> since vLLM exposes
-an OpenAI-compatible API.
+language models. Composes L<Langertha::Role::OpenAICompatible> since vLLM
+exposes an OpenAI-compatible API.
 
 Both C<url> and C<model> are required. The URL must include the C</v1>
 path prefix (e.g., C<http://localhost:8000/v1>). The API key defaults to
@@ -84,11 +99,11 @@ B<THIS API IS WORK IN PROGRESS>
 
 =item * L<https://docs.vllm.ai/> - vLLM documentation
 
-=item * L<Langertha::Engine::OpenAI> - Parent engine (OpenAI-compatible API)
+=item * L<Langertha::Role::OpenAICompatible> - OpenAI API format role
 
 =item * L<Langertha::Role::Tools> - MCP tool calling interface
 
-=item * L<Langertha> - Main Langertha documentation
+=item * L<Langertha::Engine::OllamaOpenAI> - Another self-hosted OpenAI-compatible engine
 
 =back
 
