@@ -1,6 +1,6 @@
 package Langertha::Role::Chat;
 # ABSTRACT: Role for APIs with normal chat functionality
-our $VERSION = '0.200';
+our $VERSION = '0.201';
 use Moose::Role;
 use Future::AsyncAwait;
 use Carp qw( croak );
@@ -209,6 +209,7 @@ sub _process_stream_buffer {
   return \@chunks;
 }
 
+with 'Langertha::Role::ThinkTag';
 with 'Langertha::Role::Langfuse';
 
 
@@ -226,7 +227,7 @@ Langertha::Role::Chat - Role for APIs with normal chat functionality
 
 =head1 VERSION
 
-version 0.200
+version 0.201
 
 =head1 SYNOPSIS
 
@@ -392,14 +393,14 @@ need the final result.
 
 =over
 
-=item * L<Langertha> - Main Langertha documentation
+=item * L<Langertha::Role::Langfuse> - Observability integration (composed by this role)
+
+=item * L<Langertha::Role::SystemPrompt> - System prompt injection
 
 =item * L<Langertha::Role::Streaming> - Stream parsing (SSE / NDJSON)
 
 =item * L<Langertha::Role::Tools> - Tool calling on top of chat
 
-=item * L<Langertha::Role::SystemPrompt> - System prompt injection
-
 =item * L<Langertha::Role::Models> - Model selection
 
 =item * L<Langertha::Stream> - Stream iterator
