@@ -1,6 +1,6 @@
 package Langertha::Role::OpenAICompatible;
 # ABSTRACT: Role for OpenAI-compatible API format
-our $VERSION = '0.200';
+our $VERSION = '0.201';
 use Moose::Role;
 use File::ShareDir::ProjectDistDir qw( :all );
 use Carp qw( croak );
@@ -116,15 +116,17 @@ sub chat_response {
   my ( $self, $response ) = @_;
   my $data = $self->parse_response($response);
   my $choice = $data->{choices}[0];
+  my $msg = $choice->{message} || {};
   require Langertha::Response;
   return Langertha::Response->new(
-    content       => $choice->{message}{content} // '',
+    content       => $msg->{content} // '',
     raw           => $data,
     $data->{id} ? ( id => $data->{id} ) : (),
     $data->{model} ? ( model => $data->{model} ) : (),
     defined $choice->{finish_reason} ? ( finish_reason => $choice->{finish_reason} ) : (),
     $data->{usage} ? ( usage => $data->{usage} ) : (),
     $data->{created} ? ( created => $data->{created} ) : (),
+    defined $msg->{reasoning_content} ? ( thinking => $msg->{reasoning_content} ) : (),
   );
 }
 
@@ -265,7 +267,7 @@ Langertha::Role::OpenAICompatible - Role for OpenAI-compatible API format
 
 =head1 VERSION
 
-version 0.200
+version 0.201
 
 =head1 SYNOPSIS
 
@@ -484,17 +486,21 @@ tool calls), then one C<role =E<gt> 'tool'> message per result.
 
 =item * L<Langertha::Engine::OpenAI> - OpenAI engine
 
-=item * L<Langertha::Engine::OllamaOpenAI> - Ollama OpenAI-compatible engine
-
-=item * L<Langertha::Engine::AKIOpenAI> - AKI.IO OpenAI-compatible engine
-
 =item * L<Langertha::Engine::DeepSeek> - DeepSeek engine
 
 =item * L<Langertha::Engine::Groq> - Groq engine
 
 =item * L<Langertha::Engine::Mistral> - Mistral engine
 
-=item * L<Langertha> - Main Langertha documentation
+=item * L<Langertha::Engine::vLLM> - vLLM inference server
+
+=item * L<Langertha::Engine::NousResearch> - Nous Research Hermes engine
+
+=item * L<Langertha::Engine::Perplexity> - Perplexity Sonar engine
+
+=item * L<Langertha::Engine::OllamaOpenAI> - Ollama OpenAI-compatible engine
+
+=item * L<Langertha::Engine::AKIOpenAI> - AKI.IO OpenAI-compatible engine
 
 =back
 
