@@ -1,6 +1,6 @@
 package Langertha::Role::Tools;
 # ABSTRACT: Role for MCP tool calling support
-our $VERSION = '0.200';
+our $VERSION = '0.201';
 use Moose::Role;
 use Future::AsyncAwait;
 use Carp qw( croak );
@@ -161,10 +161,13 @@ async sub chat_with_tools_f {
 
     # No tool calls means the LLM is done — return final text
     unless (@$tool_calls) {
-      if ($self->hermes_tools) {
-        return $self->_hermes_text_content($data);
+      my $text = $self->hermes_tools
+        ? $self->_hermes_text_content($data)
+        : $self->response_text_content($data);
+      if ($self->think_tag_filter) {
+        ($text) = $self->filter_think_content($text);
       }
-      return $self->response_text_content($data);
+      return $text;
     }
 
     # Execute each tool call via the appropriate MCP server
@@ -267,7 +270,7 @@ Langertha::Role::Tools - Role for MCP tool calling support
 
 =head1 VERSION
 
-version 0.200
+version 0.201
 
 =head1 SYNOPSIS
 
@@ -408,9 +411,9 @@ exceeded. Returns a L<Future> that resolves to the final text response.
 
 =over
 
-=item * L<Langertha> - Main Langertha documentation
+=item * L<Langertha::Role::Chat> - Chat role this is built on top of
 
-=item * L<Langertha::Role::Chat> - Chat role required by this role
+=item * L<Langertha::Raider> - Autonomous agent with persistent history using tools
 
 =item * L<Net::Async::MCP> - MCP client used as tool provider
 
